from redisconnection import logger, redis_connection


def test_connection():
    rd = redis_connection.RedisConnection()
    conn = rd.connection
    rd.close_connection()


if __name__ == '__main__':
    logger.warning(f'Executing {__file__}')
    test_connection()







from redisconnection import logger
from redis import Redis
import os


class RedisConnection:
    def __init__(self):
        logger.debug('Initiating Redis Connection Class')
        self._connection_parameter = None
        self._connection = None

    # Use only if you want to pass the arguments
    def set_connection_parameter(self, **kwargs):
        self._connection_parameter = {
            "user": os.environ.get('REDIS_USER') if not kwargs.get('user') else kwargs.get('user'),
            "password": os.environ.get('REDIS_PASSWORD') if not kwargs.get('password') else kwargs.get('password'),
            "host": os.environ.get('REDIS_HOST') if not kwargs.get('host') else kwargs.get('host'),
            "port": os.environ.get('REDIS_PORT') if not kwargs.get('port') else kwargs.get('port'),
            "database": os.environ.get('REDIS_DATABASE') if not kwargs.get('database') else kwargs.get('database')
        }

    def get_connection_parameter(self):
        return self._connection_parameter

    @property
    def connection(self):
        if self._connection is None:
            self.set_connection()
        return self._connection

    def set_connection(self):
        if self._connection_parameter is None:
            self.set_connection_parameter()

        logger.debug('Creating redis connection')
        conn_pool = Redis(
            password=self._connection_parameter['password'],
            host=self._connection_parameter['host'],
            port=self._connection_parameter['port'],
            db=self._connection_parameter['database'])

        self._connection = conn_pool

        try:
            self._connection.ping()
            logger.info('Redis Connection Successful. Connection={}'.format(str(self._connection)))
        except Exception as ce:
            logger.error('Error in making redis connection with host={}, port={}, database={}'.format(
                self._connection_parameter['host'], self._connection_parameter['port'],
                self._connection_parameter['database']), exc_info=True)
            raise Exception("Connection Error with Redis connection={}".format(str(self._connection)))

    # todo
    def close_connection(self):
        if self._connection is not None:
            self._connection = None



import logging
import os
from dotenv import load_dotenv
from logging import config as logging_config
logger = logging.getLogger()


def init_app():
    global logger
    if not load_dotenv(override=False):
        logger.error('Could not find any .env file. The module will depend on system env only')

    # if application handlers , do nothing , else add just stdout handler
    if not logger.hasHandlers():
        app_logging_config = {
            'version': 1,
            'loggers': {
                '': {  # root logger
                    'level': os.getenv('LOG_LEVEL', 'INFO'),
                    'handlers': ['console'],
                },
            },
            'handlers': {
                'console': {
                    'level': os.getenv('LOG_LEVEL', 'INFO'),
                    'formatter': 'info',
                    'class': 'logging.StreamHandler',
                    'stream': 'ext://sys.stdout',
                },
            },
            'formatters': {
                'info': {
                    'format': '%(asctime)s-%(module)s-%(lineno)s::%(levelname)s:: %(message)s'
                }
            },
        }

        logging_config.dictConfig(app_logging_config)
    logger.debug('redisconnection library initiated')


if __name__ == 'redisconnection':
    init_app()



from setuptools import setup

setup(
    name='redisconnection',
    packages=['redisconnection'],
    package_dir={'redisconnection': 'src/redisconnection'},
    version='0.0.3',
    license='MIT',
    platforms='cross-platfom, platform-independent',
    description='Redis Connections and Queries Handler',
    long_description='Dependencies: redis',
    author='Yogesh Yadav',
    author_email='yogesh@byprice.com',
    url='https://github.com/ByPrice/redisconnection',
    download_url='https://github.com/ByPrice/redisconnection',
    keywords=['redis', 'redis-queries', 'redis-connection-wrapper'],
    install_requires=[
        'redis==3.4.1', 'python-dotenv==0.12.0'
    ],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'Programming Language :: Python :: 3.6',
    ],
)
